

InverseTransmission
====================================

.. currentmodule:: poppy.poppy_core

.. autoclass:: InverseTransmission
   :show-inheritance:

   
     
   

   
   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~InverseTransmission.getPhasor

   
   

   
   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: getPhasor

   
   